====
News
====

Next Release
============

A final 12.0 version is planned for end of 2013.

Announces
=========

2013-11-12
----------

@mariocesar: We have a new team of mantainers for sorl-thumbnail. I wan't to encourage
all developers that have fixes, forks and new features to talk in the irc channel of
the project. irc://freenode.net/#sorl-thumbnail


2013-11-09
----------

@nikko: Unfortunately I no longer work with Django so my motivation to keep developing
for sorl-thumbnail is very low. If you are interested in taking over this
project please send an email to mikko@aino.se explaing why you are the perfect
fit for owning this project.

.. include:: ../CHANGES.rst
